@@ -1,6 +1,6 @@
 /* 
  *
- * $Id: k3bdvdjob.cpp 438882 2005-07-26 13:18:34Z trueg $
+ * $Id: k3bdvdjob.cpp 528555 2006-04-11 12:17:49Z trueg $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
@@ -98,6 +98,17 @@ void K3bDvdJob::start()
   emit started();
   emit newTask( i18n("Preparing data") );
 
+  m_doc->prepareFilenames();
+  if( m_doc->needToCutFilenames() ) {
+    if( !questionYesNo( i18n("Some filenames need to be shortened due to the %1 char restriction "
+			     "of the Joliet extensions. Continue anyway?")
+			.arg( m_doc->isoOptions().jolietLong() ? 103 : 64 ) ) ) {
+      emit canceled();
+      emit finished( false );
+      return;
+    }
+  }
+
   m_canceled = false;
   m_writingStarted = false;
   d->copies = m_doc->copies();
@@ -182,6 +193,8 @@ void K3bDvdJob::prepareGrowisofsImager()
     connect( m_growisofsImager, SIGNAL(debuggingOutput(const QString&, const QString&)), 
 	     this, SIGNAL(debuggingOutput(const QString&, const QString&)) );
   }
+
+  m_growisofsImager->setUsedMultiSessionMode( d->usedMultiSessionMode );
 }
 
 
@@ -546,7 +559,7 @@ void K3bDvdJob::slotDetermineMultiSessionMode( K3bDevice::DeviceHandler* dh )
 
     // try to check the filesystem size
     K3bIso9660 iso( m_doc->burner() );
-    if( iso.open() && info.capacity() - iso.primaryDescriptor().volumeSpaceSize >= m_doc->length() ) {
+    if( iso.open() && info.capacity() - iso.primaryDescriptor().volumeSpaceSize >= ( m_doc->burningSize() / 2048 ) ) {
       d->usedMultiSessionMode = K3bDataDoc::CONTINUE;
     }
     else {
@@ -560,7 +573,7 @@ void K3bDvdJob::slotDetermineMultiSessionMode( K3bDevice::DeviceHandler* dh )
     //  2. the project does fit and fills up the CD -> finish multisession
     //  3. the project does fit and does not fill up the CD -> continue multisession
     //
-    if( m_doc->size() > info.remainingSize().mode1Bytes() )
+    if( m_doc->size() > info.remainingSize().mode1Bytes() && m_doc->size() == m_doc->burningSize() )
       d->usedMultiSessionMode = K3bDataDoc::NONE;
     else if( m_doc->size() >= info.remainingSize().mode1Bytes()*9/10 )
       d->usedMultiSessionMode = K3bDataDoc::FINISH;
@@ -568,7 +581,14 @@ void K3bDvdJob::slotDetermineMultiSessionMode( K3bDevice::DeviceHandler* dh )
       d->usedMultiSessionMode = K3bDataDoc::CONTINUE;
   }
   else {
-    d->usedMultiSessionMode = K3bDataDoc::NONE;
+    //
+    // We only close the DVD if the project fills it up almost completely (90%)
+    //
+    if( m_doc->size() >= info.capacity().mode1Bytes()*9/10 ||
+	m_doc->writingMode() == K3b::DAO )
+      d->usedMultiSessionMode = K3bDataDoc::NONE;
+    else
+      d->usedMultiSessionMode = K3bDataDoc::START;
   }
 
   if( d->usedMultiSessionMode != K3bDataDoc::NONE ) {
@@ -691,14 +711,14 @@ bool K3bDvdJob::waitForDvd()
 
 	// FIXME: DVD-R DL jump and stuff
 
-	if( m_doc->writingMode() == K3b::DAO ||
-	    ( m_doc->writingMode() == K3b::WRITING_MODE_AUTO &&
-	      d->usedMultiSessionMode == K3bDataDoc::NONE ) )
+	if( m_doc->writingMode() == K3b::DAO )
+//	    ( m_doc->writingMode() == K3b::WRITING_MODE_AUTO &&
+//	      d->usedMultiSessionMode == K3bDataDoc::NONE ) )
 	  emit infoMessage( i18n("Writing %1 in DAO mode.").arg( K3bDevice::mediaTypeString(d->foundMedia, true) ), INFO );
 
 	else {
 	  // check if the writer supports writing sequential and thus multisession
-	  if( !m_doc->burner()->featureCurrent( K3bDevice::FEATURE_INCREMENTAL_STREAMING_WRITABLE ) ) {
+	  if( m_doc->burner()->featureCurrent( K3bDevice::FEATURE_INCREMENTAL_STREAMING_WRITABLE ) == 0 ) {
 	    if( KMessageBox::warningYesNo( qApp->activeWindow(),
 					   i18n("Your writer (%1 %2) does not support Incremental Streaming with %3 "
 						"media. Multisession will not be possible. Continue anyway?")
@@ -765,4 +785,10 @@ QString K3bDvdJob::jobDetails() const
       .arg(KIO::convertSize( m_doc->size() ));
 }
 
+
+bool K3bDvdJob::hasBeenCanceled() const
+{
+  return m_canceled;
+}
+
 #include "k3bdvdjob.moc"
