@@ -1,6 +1,6 @@
 /*
  *
- * $Id: k3bdevice.cpp 423353 2005-06-08 06:20:40Z trueg $
+ * $Id: k3bdevice.cpp 553928 2006-06-22 14:30:38Z trueg $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
@@ -63,6 +63,10 @@ typedef unsigned char u8;
 #define CD_FRAMESIZE_RAW 2352
 #endif
 
+#ifdef Q_OS_NETBSD
+#include <sys/cdio.h>
+#endif
+
 #ifdef HAVE_RESMGR
 extern "C" {
 #include <resmgr.h>
@@ -100,7 +104,7 @@ const char* K3bDevice::Device::cdrdao_drivers[] =
   };
 
 
-#ifdef Q_OS_LINUX
+#if defined(Q_OS_LINUX) || defined(Q_OS_NETBSD)
 int K3bDevice::openDevice( const char* name, bool write )
 {
   int fd = -1;
@@ -143,6 +147,9 @@ public:
 #ifdef Q_OS_LINUX
       deviceFd(-1),
 #endif
+#ifdef Q_OS_NETBSD
+      deviceFd(-1),
+#endif
 #ifdef Q_OS_FREEBSD
       cam(0),
 #endif
@@ -157,6 +164,9 @@ public:
 #ifdef Q_OS_LINUX
   int deviceFd;
 #endif
+#ifdef Q_OS_NETBSD
+  int deviceFd;
+#endif
 #ifdef Q_OS_FREEBSD
   struct cam_device *cam;
 #endif
@@ -1465,8 +1475,22 @@ bool K3bDevice::Device::fixupToc( K3bDevice::Toc& toc ) const
 
 bool K3bDevice::Device::block( bool b ) const
 {
+#ifdef Q_OS_NETBSD
+  bool success = false;
+  bool needToClose = !isOpen();
+  int arg = b ? 1 : 0;
+
+  if( open() ) {
+    if ( ::ioctl( d->deviceFd, DIOCLOCK, &arg ) >= 0)
+      success = true;
+    if( needToClose )
+      close();
+  }
+  return success;
+#else
   ScsiCommand cmd( this );
   cmd[0] = MMC_PREVENT_ALLOW_MEDIUM_REMOVAL;
+  cmd[5] = 0; // Necessary to set the proper command length
   if( b )
     cmd[4] = 0x01;
   int r = cmd.transport();
@@ -1475,6 +1499,7 @@ bool K3bDevice::Device::block( bool b ) const
     kdDebug() << "(K3bDevice::Device) MMC ALLOW MEDIA REMOVAL failed." << endl;
 
   return ( r == 0 );
+#endif
 }
 
 bool K3bDevice::Device::rewritable() const
@@ -1496,8 +1521,22 @@ bool K3bDevice::Device::rewritable() const
 
 bool K3bDevice::Device::eject() const
 {
+#ifdef Q_OS_NETBSD
+  bool success = false;
+  bool needToClose = !isOpen();
+  int arg = 0;
+
+  if( open() ) {
+    if ( ::ioctl( d->deviceFd, DIOCEJECT, &arg ) >= 0)
+      success = true;
+    if( needToClose )
+      close();
+  }
+  return success;
+#else
   ScsiCommand cmd( this );
   cmd[0] = MMC_START_STOP_UNIT;
+  cmd[5] = 0; // Necessary to set the proper command length
 
   // Since all other eject methods I saw also start the unit before ejecting
   // we do it also although I don't know why...
@@ -1507,15 +1546,31 @@ bool K3bDevice::Device::eject() const
   cmd[4] = 0x2;    // LoEj = 1, Start = 0
 
   return !cmd.transport();
+#endif
 }
 
 
 bool K3bDevice::Device::load() const
 {
+#ifdef Q_OS_NETBSD
+  bool success = false;
+  bool needToClose = !isOpen();
+  int arg = 0;
+
+  if( open() ) {
+    if ( ::ioctl( d->deviceFd, CDIOCCLOSE, &arg ) >= 0)
+      success = true;
+    if( needToClose )
+      close();
+  }
+  return success;
+#else
   ScsiCommand cmd( this );
   cmd[0] = MMC_START_STOP_UNIT;
   cmd[4] = 0x3;    // LoEj = 1, Start = 1
+  cmd[5] = 0;      // Necessary to set the proper command length
   return !cmd.transport();
+#endif
 }
 
 
@@ -1557,7 +1612,7 @@ bool K3bDevice::Device::open( bool write ) const
   }
   return (d->cam != 0);
 #endif
-#ifdef Q_OS_LINUX
+#if defined(Q_OS_LINUX) || defined(Q_OS_NETBSD)
   if( d->deviceFd == -1 )
     d->deviceFd = openDevice( QFile::encodeName(devicename()), write );
 
@@ -1574,7 +1629,7 @@ void K3bDevice::Device::close() const
     d->cam = 0;
   }
 #endif
-#ifdef Q_OS_LINUX
+#if defined(Q_OS_LINUX) || defined(Q_OS_NETBSD)
   if( d->deviceFd != -1 ) {
     ::close( d->deviceFd );
     d->deviceFd = -1;
@@ -1588,7 +1643,7 @@ bool K3bDevice::Device::isOpen() const
 #ifdef Q_OS_FREEBSD
   return d->cam;
 #endif
-#ifdef Q_OS_LINUX
+#if defined(Q_OS_LINUX) || defined(Q_OS_NETBSD)
   return ( d->deviceFd != -1 );
 #endif
 }
@@ -1609,6 +1664,7 @@ int K3bDevice::Device::currentProfile() const
   cmd[0] = MMC_GET_CONFIGURATION;
   cmd[1] = 1;
   cmd[8] = 8;
+  cmd[9] = 0;      // Necessary to set the proper command length
 
   if( cmd.transport( TR_DIR_READ, profileBuf, 8 ) ) {
     kdDebug() << "(K3bDevice::Device) GET_CONFIGURATION failed." << endl;
@@ -1807,31 +1863,7 @@ K3bDevice::DiskInfo K3bDevice::Device::diskInfo() const
 	  eda = ( data[4+9]<<16 | data[4+10] << 8 | data[4+11] );
 	  ea0 = ( data[4+13]<<16 | data[4+14] << 8 | data[4+15] );
 
-	  kdDebug() << "First sec data area: " << sda.toString()
-		    << " (LBA " << QString::number(sda.lba())
-		    << ") (" << QString::number(sda.mode1Bytes()) << " Bytes) ("
-		    << KIO::convertSize(sda.mode1Bytes()) << ")" << endl;
-	  kdDebug() << "Last sec data area: " << eda.toString()
-		    << " (LBA " << QString::number(eda.lba())
-		    << ") (" << QString::number(eda.mode1Bytes()) << " Bytes) ("
-		    << KIO::convertSize(eda.mode1Bytes()) << ")" << endl;
-	  kdDebug() << "Last sec layer 1: " << ea0.toString()
-		    << " (LBA " << QString::number(ea0.lba())
-		    << ") (" << QString::number(ea0.mode1Bytes()) << " Bytes) ("
-		    << KIO::convertSize(ea0.mode1Bytes()) << ")" << endl;
-
-
 	  K3b::Msf da0 = ea0 - sda + 1;
-	  K3b::Msf da1 = eda - ea0;
-	  kdDebug() << "Layer 1 length: " << da0.toString()
-		    << " (LBA " << QString::number(da0.lba())
-		    << ") (" << QString::number(da0.mode1Bytes()) << " Bytes) ("
-		    << KIO::convertSize(da0.mode1Bytes()) << ")" << endl;
-	  kdDebug() << "Layer 2 length: " << da1.toString()
-		    << " (LBA " << QString::number(da1.lba())
-		    << ") (" << QString::number(da1.mode1Bytes()) << " Bytes) ("
-		    << KIO::convertSize(da1.mode1Bytes()) << ")" << endl;
-
 	  inf.m_numLayers = ((data[6]&0x60) == 0 ? 1 : 2);
 	  inf.m_firstLayerSize = da0;
 
@@ -2196,6 +2228,7 @@ void K3bDevice::Device::checkFeatures()
   ScsiCommand cmd( this );
   cmd[0] = MMC_GET_CONFIGURATION;
   cmd[1] = 2;
+  cmd[9] = 0;      // Necessary to set the proper command length
 
 
   //
