@@ -1,9 +1,9 @@
 /*
  *
- * $Id: main.cpp 442330 2005-08-02 10:39:06Z trueg $
+ * $Id: main.cpp 531404 2006-04-19 09:26:56Z trueg $
  *
  * This file is part of the K3b project.
- * Copyright (C) 1998-2005 Sebastian Trueg <trueg@k3b.org>
+ * Copyright (C) 1998-2006 Sebastian Trueg <trueg@k3b.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -29,6 +29,7 @@
 #include <qfile.h>
 #include <qcstring.h>
 #include <qdatastream.h>
+#include <qtimer.h>
 
 #include <stdlib.h>
 
@@ -38,7 +39,7 @@
 
 #include <config.h>
 
-static const char* appVersion = "0.12.4a";
+static const char* appVersion = "0.12.16";
 static const char* description = I18N_NOOP("A CD and DVD burning application");
 
 
@@ -70,7 +71,7 @@ int main( int argc, char* argv[] )
 {
   KAboutData aboutData( "k3b", I18N_NOOP("K3b"),
 			appVersion, description, KAboutData::License_GPL,
-			I18N_NOOP("(c) 1999 - 2005, Sebastian Trüg and the K3b Team"), 0, "http://www.k3b.org" );
+			I18N_NOOP("(c) 1999 - 2006, Sebastian Trüg and the K3b Team"), 0, "http://www.k3b.org" );
   aboutData.addAuthor("Sebastian Trüg",I18N_NOOP("Maintainer"), "trueg@k3b.org");
   aboutData.addAuthor("Thomas Froescher",I18N_NOOP("VideoDVD ripping and video encoding"), "tfroescher@k3b.org");
   aboutData.addAuthor("Christian Kvasny",I18N_NOOP("VideoCD Project and VideoCD ripping"), "chris@k3b.org");
@@ -113,7 +114,9 @@ int main( int argc, char* argv[] )
 		  << " current is: " << KGlobal::locale()->language() << endl;
   
     K3bApplication app;
-    app.init();
+
+    // we need a running app for the init method
+    QTimer::singleShot( 0, &app, SLOT(init()) );
 
     return app.exec();
   }
